@@ -144,15 +144,6 @@ class AbstractFunctionalArchitecture(
         (NS, "ComponentExchangeRealization"),
     )
 
-    @property
-    def root_function(self) -> AbstractFunction:
-        """Returns the first function in the function_pkg."""
-        pkg = self.function_pkg
-        assert pkg is not None
-        if not pkg.functions:
-            raise RuntimeError(f"Package {pkg._short_repr_()} is empty")
-        return pkg.functions[0]
-
     @property
     def all_functions(self) -> m.ElementList[AbstractFunction]:
         return self._model.search((NS, "AbstractFunction"), below=self)
@@ -292,29 +283,23 @@ class FunctionalChain(
 
     @property
     def involved_functions(self) -> m.ElementList[AbstractFunction]:
-        objs = self.involvements.by_class(
-            FunctionalChainInvolvementFunction,
-        ).map("involved")
+        objs = self.involvements.map("involved").by_class(AbstractFunction)
         return m.ElementList(self._model, objs._elements, legacy_by_type=True)
 
     @property
     def involved_links(self) -> m.ElementList[FunctionalExchange]:
-        objs = self.involvements.by_class(
-            FunctionalChainInvolvementLink,
-        ).map("involved")
+        objs = self.involvements.map("involved").by_class(FunctionalExchange)
         return m.ElementList(self._model, objs._elements, legacy_by_type=True)
 
     @property
     def involved_chains(self) -> m.ElementList[FunctionalChain]:
-        return self.involvements.by_class(
-            FunctionalChainReference,
-        ).map("involved")
+        return self.involvements.map("involved").by_class(FunctionalChain)
 
     @property
     def involved(self) -> m.ElementList[AbstractFunction | FunctionalExchange]:
-        objs = self.involvements.by_class(
-            FunctionalChainInvolvementFunction, FunctionalChainInvolvementLink
-        ).map("involved")
+        objs = self.involvements.map("involved").by_class(
+            AbstractFunction, FunctionalExchange
+        )
         return m.ElementList(self._model, objs._elements, legacy_by_type=True)
 
     involving_chains = m.Backref["FunctionalChain"](
